---
feature_story: FS_18_64_57_18
feature_title: function with indefinite input data envelopes like varargs
feature_status: TEST
---

# Feature

Some search has to single out one `data_envelope`,
but this feature is for functions that need to accept arbitrary number of `data_envelope`-s -
all of which are from search for of `data_envelope`-s filtered by command line args (just not singled out).

The feature is similar to function varargs (in programming languages) -
here, instead of arbitrary number of trailing function arguments,
the search result for the trailing `envelop_container` may contain number of `data_envelope`-s.

# Possible future

TODO_75_52_01_67: `arg_bucket`-s to support multiple var args:
Note that it is logically possible to allow any `envelope_container` search for arbitrary `data_envelope`-s,
but this requires some rules how to decide (using `arg_bucket`-s):
*   where interrogation for args of curr `envelope_container` ends
*   where interrogation for args of next `envelope_container` starts
